@@ -167,7 +167,10 @@ class ImageParam(DataSet):
         self.metadata = {}
         for attr_str in dir(value):
             if attr_str != "GroupLength":
-                self.metadata[attr_str] = getattr(value, attr_str)
+                try:
+                    self.metadata[attr_str] = getattr(value, attr_str)
+                except AttributeError:
+                    pass
 
     @property
     def template(self):
@@ -1332,13 +1335,11 @@ class ImageFT(ObjectFT):
             image.title = filename
             image.data = data
             if osp.splitext(filename)[1].lower() == ".dcm":
-                try:
-                    # pydicom 1.0
-                    from pydicom import dicomio
-                except ImportError:
-                    # pydicom 0.9
-                    import dicom as dicomio
-                image.template = dicomio.read_file(filename, stop_before_pixels=True)
+                from pydicom import dicomio
+
+                image.template = dicomio.read_file(
+                    filename, stop_before_pixels=True, force=True
+                )
             self.add_object(image)
 
     def save_image(self):
